==> nbdkit_1.42.6.orig.tar.gz: nbdkit-1.42.6/filters/xz/blkcache.h <==
/* nbdkit
 * Copyright Red Hat
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * * Neither the name of Red Hat nor the names of its contributors may be
 * used to endorse or promote products derived from this software without
 * specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY RED HAT AND CONTRIBUTORS ''AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL RED HAT OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef NBDKIT_BLKCACHE_H
#define NBDKIT_BLKCACHE_H

typedef struct blkcache blkcache;

typedef struct blkcache_stats {
  size_t hits;
  size_t misses;
} blkcache_stats;

extern blkcache *new_blkcache (size_t maxdepth);
extern void free_blkcache (blkcache *) __attribute__ ((__nonnull__ (1)));
extern char *get_block (blkcache *, uint64_t offset,
                        uint64_t *start, uint64_t *size)
  __attribute__ ((__nonnull__ (1, 3, 4)));
extern int put_block (blkcache *, uint64_t start, uint64_t size, char *data)
  __attribute__ ((__nonnull__ (1, 4)));
extern void blkcache_get_stats (blkcache *, blkcache_stats *ret)
  __attribute__ ((__nonnull__ (1, 2)));

#endif /* NBDKIT_XZFILE_H */

==> nbdkit_1.46.2.orig.tar.gz: nbdkit-1.46.2/filters/xz/blkcache.h <==
/* nbdkit
 * Copyright Red Hat
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * * Neither the name of Red Hat nor the names of its contributors may be
 * used to endorse or promote products derived from this software without
 * specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY RED HAT AND CONTRIBUTORS ''AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL RED HAT OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef NBDKIT_BLKCACHE_H
#define NBDKIT_BLKCACHE_H

typedef struct blkcache blkcache;

typedef struct blkcache_stats {
  size_t hits;
  size_t misses;
} blkcache_stats;

extern blkcache *new_blkcache (size_t maxdepth);
extern void free_blkcache (blkcache *) NBDKIT_ATTRIBUTE_NONNULL ((1));
extern char *get_block (blkcache *, uint64_t offset,
                        uint64_t *start, uint64_t *size)
  NBDKIT_ATTRIBUTE_NONNULL ((1, 3, 4));
extern int put_block (blkcache *, uint64_t start, uint64_t size, char *data)
  NBDKIT_ATTRIBUTE_NONNULL ((1, 4));
extern void blkcache_get_stats (blkcache *, blkcache_stats *ret)
  NBDKIT_ATTRIBUTE_NONNULL ((1, 2));

#endif /* NBDKIT_XZFILE_H */
